@@ -58,6 +58,7 @@ class Task(BaseIserv):
 
         self.author = None
         self.description = None
+        self.provided_files = {}
 
     def get_details(self, path="/iserv/exercise/show/"):
         self._login()
@@ -69,6 +70,22 @@ class Task(BaseIserv):
             task_details.append(row.find_all("td"))
         self.author = task_details[0][0].find("a").text
         self.description = task_details[3][0].text
+        try:
+            provided_files = task_details[5][0].find("ul").find_all("li")
+            provided_files_list = []
+            for file in provided_files:
+                provided_files_dict = {"filename": file.find("a").text.split("\n")[0].strip(),
+                                       "size": file.find("a").text.split("\n")[1].strip(),
+                                       "link": file.find("a")["href"],
+                                       }
+                try:
+                    provided_files_dict["description"] = file.text.split("\n")[1].strip().split("-")[1].strip()
+                except IndexError:
+                    provided_files_dict["description"] = ""
+                provided_files_list.append(provided_files_dict)
+            self.provided_files = provided_files_list
+        except IndexError:
+            pass
         return self
 
 
